# amirouter
- version: 0.0.3

Java multithreaded standalone application that will connect to one or multiple Asterisk servers using AMI protocol (preferably using a library) and trigger a callback function when receiving events.
At the same time, one or multiple clients can connect to this Java application using a predefined port (like 5039) and using the AMI protocol receive the events from the asterisk servers and send commands to one or multiple clients.
When an event is received from the asterisk server, the application will send the same event to all or some of the clients connected.
When a command is received from any of the clients connected, the same command will be sent to the asterisk server.



## Requirements

Building the project requires:
1. Java 13+
2. Maven (3.8.0+)


If **maven** not installed
```sh
sudo apt install maven
```


## Prod

### Installation
#### Maven
1. At first generate the JAR by executing:

```shell
cd ~/projects/amirouter
mvn clean install spring-boot:repackage -DskipTests -Pamirouter
```

2. Copy `target/amirouter-0.0.3-SNAPSHOT.jar` to the directory you want run from (e.g.`releases` ) :
```sh
mkdir -p releases/amirouter
cp target/amirouter-0.0.3-SNAPSHOT.jar ./releases/amirouter/
cp src/main/resources/application.properties ./releases/amirouter/
cp amirouter-server-config.yaml ./releases/amirouter/
```


### Run
1. Create config file for the server : `amirouter-server-config.yaml` 

```yaml
--- 
# amirouter listen infos
listenHost: 127.0.0.1
listenPort: 5039
usesipregs: true
#usesipregs: false

# remote asterisk server list
asteriskServers:
   - nodename: srv02
     hostname: 138.201.140.216
     port: 5038
     username: jano
     password: YFMnVFjQ
     
   - nodename: srv04
     hostname: 95.217.87.47
     port: 5038
     username: jano
     password: YFMnVFjQ
      
```

- run amirouter interactivelly (with autocompletion)
```sh
cd ~/projects/amirouter/releases
SPRING_CONFIG_LOCATION=./amirouter/application.properties \
	java -jar amirouter/amirouter-0.0.3-SNAPSHOT.jar

...
Server:> help
Server:> help start
Server:> start --config-file ./amirouter/amirouter-server-config.yaml
```

To exit enter `quit` or `exit`:
```sh
Server:> quit
Server:> exit
```


- run amirouter with no user interaction

```sh
SPRING_CONFIG_LOCATION=./amirouter/application.properties \
  java -jar amirouter/amirouter-0.0.3-SNAPSHOT.jar \
  start --config-file ./amirouter/amirouter-server-config.yaml
```

Send `^C` to stop amirouter


## Run in dev mode

```shell
cd ~/projects/amirouter
SPRING_CONFIG_LOCATION=./src/main/resources/application-dev.properties \
	mvn spring-boot:run -Dstart-class=com.amirouter.server.ServerApp -Pamirouter 
```

## Extending the application
Sources files are located under : `src/main/java/com/amirouter/server/` 

