package com.amirouter.server.CLI;

import java.io.IOException;

import javax.annotation.PreDestroy;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.shell.ExitRequest;
import org.springframework.shell.component.PathInput;
import org.springframework.shell.component.PathInput.PathInputContext;
import org.springframework.shell.context.InteractionMode;
import org.springframework.shell.standard.AbstractShellComponent;
import org.springframework.shell.standard.ShellComponent;
import org.springframework.shell.standard.ShellMethod;
import org.springframework.shell.standard.ShellOption;

import com.amirouter.server.services.ConnManagerService;

/**
 * Amirouter command line interface definition
 */
@ShellComponent
public class ConnManagerCommand extends AbstractShellComponent {

	@Autowired
	private ConnManagerService connectionManagerService;

	@ShellMethod(value = "start amirouter server", group = "AmiRouterServer Commands")
	public void start(@ShellOption(value = { "-c",
			"--config-file" }, help = "path to the configuration file (optional)", defaultValue = ShellOption.NULL) String configFilePath) {

		try {

			if (configFilePath != null) {
				connectionManagerService.start(configFilePath);
				return;
			}

			PathInput component = new CustomPathInput(getTerminal(), "Enter config file path");
			component.setResourceLoader(getResourceLoader());
			component.setTemplateExecutor(getTemplateExecutor());
			PathInputContext context = component.run(PathInputContext.empty());

			if (context.getResultValue() != null) {

				if (context.getResultValue().toFile().exists()) {
					String userConfigFilePath = context.getResultValue().toRealPath().toString();

					connectionManagerService.start(userConfigFilePath);

				} else {
					System.err
							.println(String.format("%s : doesn't exist", context.getResultValue().toFile().toString()));
				}

				return;
			}

		} catch (IOException e) {
			e.printStackTrace();
		}

		System.err.println("no config file passed");

	}

	@ShellMethod(value = "stop amirouter server", group = "AmiRouterServer Commands")
	public void stop() {
		connectionManagerService.stop();
	}

	@ShellMethod(value = "show current amirouter server configuraiton", group = "AmiRouterServer Commands")
	public void config() {
		connectionManagerService.showConfigContent();
	}

	@ShellMethod(value = "return current current state", group = "AmiRouterServer Commands")
	public String status() {
		if (connectionManagerService.isStarted()) {
			return "up".toUpperCase();
		}

		return "down".toUpperCase();
	}

	@ShellMethod(value = "Exit the server application.", key = { "quit",
			"exit" }, interactionMode = InteractionMode.INTERACTIVE, group = "Built-In Commands")
	public void quit() {
		connectionManagerService.stop();
		throw new ExitRequest();
	}

	@PreDestroy
	public void preDestroy() {
		if (connectionManagerService.isStarted()) {
			connectionManagerService.stop();
		}

	}

}
