package com.amirouter.server.ami;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import com.amirouter.server.asterisk.AsteriskProxy;
import com.amirouter.server.model.MuManageruser;
import com.amirouter.server.util.ServerConfig;

/**
 * Manage remote connected client context
 */
public class AmiClientContext {

	private MuManageruser currentUser = null;

	private ServerConfig srvConfig = null;

	private Map<String, String> asteriskNodenameToIp = null;

	private ConcurrentHashMap<String, AsteriskProxy> addrToAsteriskProxies = null;

	/**
	 * Constructor
	 * 
	 * @param srvConfig             reference the current amirouter server config
	 * @param asteriskNodenameToIp  mapping of asterisk servers nodename to their
	 *                              IPs addresses
	 * @param addrToAsteriskProxies mapping of asterisk servers host to their proxy
	 *                              objects
	 */
	public AmiClientContext(ServerConfig srvConfig, Map<String, String> asteriskNodenameToIp,
			ConcurrentHashMap<String, AsteriskProxy> addrToAsteriskProxies) {
		this.srvConfig = srvConfig;
		this.asteriskNodenameToIp = asteriskNodenameToIp;
		this.addrToAsteriskProxies = addrToAsteriskProxies;
	}

	/**
	 * @return the currentUser
	 */
	public MuManageruser getCurrentUser() {
		return currentUser;
	}

	/**
	 * @param currentUser the currentUser to set
	 */
	public void setCurrentUser(MuManageruser currentUser) {
		this.currentUser = currentUser;
	}

	/**
	 * @return the srvConfig
	 */
	public ServerConfig getSrvConfig() {
		return srvConfig;
	}

	/**
	 * Retrieve asterisk server ip by his nodename
	 * 
	 * @param nodename nodename of the asterisk server
	 * @return the mapped ip address corresponding to the passed nodename
	 */
	public String getAsteriskIpByNodeName(String nodename) {
		return asteriskNodenameToIp.get(nodename);
	}

	/**
	 * Retrieve asterisk server proxy object by his hostname
	 * 
	 * @param asteriskHostname the hostname of asterisk server
	 * @return the corresponding proxy object. @see AsteriskProxy
	 */
	public AsteriskProxy getAsteriskProxyByHostName(String asteriskHostname) {
		return addrToAsteriskProxies.get(asteriskHostname);
	}

}
