package com.amirouter.server.ami;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import com.amirouter.server.util.Utilities;

/**
 * Ami protocol specification between amirouter and clients
 */
public class AmiSpecs {

	public static final Map<String, Boolean> AMI_LOGIN_SPEC = new LinkedHashMap<String, Boolean>() {

		private static final long serialVersionUID = 5353858790597702491L;

		{
			put("Action", true);
			put("ActionID", false);
			put("Username", true);
			put("Secret", true);
		}
	};

	public static final Map<String, Boolean> AMI_LOGOFF_SPEC = new LinkedHashMap<String, Boolean>() {

		private static final long serialVersionUID = 4277271320259135107L;

		{
			put("Action", true);
			put("ActionID", false);
		}
	};

	public static final Map<String, Boolean> AMI_EXTENSIONSTATE_SPEC = new LinkedHashMap<String, Boolean>() {

		private static final long serialVersionUID = 4277271320259135107L;

		{
			put("Action", true);
			put("ActionID", false);
			put("Exten", true);
			put("Context", true);
		}
	};

	/**
	 * Check the validity of client ami input command
	 * 
	 * @param amiCmd  the client ami input command
	 * @param amiSpec the known spec of the corresponding command
	 * @return true if the input is valid else false
	 */
	public static boolean validateSpec(Map<String, String> amiCmd, Map<String, Boolean> amiSpec) {

		List<String> ListSpecKeys = new ArrayList<String>(amiSpec.keySet());

		if (amiCmd.size() <= amiSpec.size()) {

			boolean isValid = ListSpecKeys.stream().allMatch(k ->

			// if amiCmd contain key ok else verify that key is optional
			(amiCmd.containsKey(k) && (!Utilities.isStrEmptyOrNull(amiCmd.get(k)))) || !amiSpec.get(k)

			);

			return isValid;
		}

		return false;
	}

}
