package com.amirouter.server.asterisk;

/**
 * Class to hold remote asterisk server connection informations
 *
 */
public class AsteriskInfo {

	private String nodename;
	private String hostname;
	private int port;
	private String username;
	private String password;

	/**
	 * Constructor
	 * 
	 * @param hostname hostname or ip address of the asterisk server
	 * @param port     the connection port
	 * @param username the username used for the authentication
	 * @param password the password used for the authentication
	 */
	public AsteriskInfo(String nodename, String hostname, int port, String username, String password) {
		this.nodename = nodename;
		this.hostname = hostname;
		this.port = port;
		this.username = username;
		this.password = password;
	}

	/**
	 * Default constructor (required for serialization)
	 */
	public AsteriskInfo() {
	}

	/**
	 * @return the nodename
	 */
	public String getNodename() {
		return nodename;
	}

	/**
	 * @param nodename the nodename to set
	 */
	public void setNodename(String nodename) {
		this.nodename = nodename;
	}

	/**
	 * Get the hostname or ip address of the asterisk server
	 * 
	 * @return the hostname or ip address of the asterisk server
	 */
	public String getHostname() {
		return hostname;
	}

	/**
	 * Set the hostname or ip address of the asterisk server
	 * 
	 * @param hostname the new hostname or ip address of the asterisk server
	 */
	public void setHostname(String hostname) {
		this.hostname = hostname;
	}

	/**
	 * Get the connection port
	 * 
	 * @return the connection port
	 */
	public int getPort() {
		return port;
	}

	/**
	 * Set the connection port
	 * 
	 * @param port the new connection port
	 */
	public void setPort(int port) {
		this.port = port;
	}

	/**
	 * Get the username used for the authentication
	 * 
	 * @return the username used for the authentication
	 */
	public String getUsername() {
		return username;
	}

	/**
	 * Set the username used for the authentication
	 * 
	 * @param username the new username used for the authentication
	 */
	public void setUsername(String username) {
		this.username = username;
	}

	/**
	 * Get the password used for the authentication
	 * 
	 * @return the password used for the authentication
	 */
	public String getPassword() {
		return password;
	}

	/**
	 * Set the password used for the authentication
	 * 
	 * @param password the new password used for the authentication
	 */
	public void setPassword(String password) {
		this.password = password;
	}

	@Override
	public String toString() {
		return "AsteriskInfo [nodename=" + nodename + ", hostname=" + hostname + ", port=" + port + ", username="
				+ username + ", password=" + password + "]";
	}

	

}
