package com.amirouter.server.repo;

import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

import org.hibernate.Session;
import org.hibernate.query.Query;
import org.springframework.stereotype.Repository;

import com.amirouter.server.services.AsteriskServerInfos;

/**
 * Asterisk server infos repository
 */
@Repository
public class AsteriskServerInfosRepository {

	@PersistenceContext
	private EntityManager entityManager;

	private Session getSession() {
		return entityManager.unwrap(Session.class);
	}

	/**
	 * Build a query string for the database
	 * 
	 * @param exTech     extension tech
	 * @param usesipregs config variable. @see ServerConfig
	 * @return
	 */
	public String buildServerInfosQuery(String exTech, Boolean usesipregs) {

		String queryStr = null;

		// NOTE: SELECT <alias_name> FROM <EntityClass> <alias_name>;

		switch (exTech) {
		case "SIP": {
			if (usesipregs) {
				queryStr = "select a.name,b.regserver,n.noId FROM ExExtension,NoNode n,Sipfriend a,Sipreg b where"
						+ " b.regserver=no_peername and b.regseconds ="
						+ " ( select max(c.regseconds) as maxregseconds FROM Sipreg c where b.name=c.name )"
						+ " and a.name=b.name and ex_number=:extension_number and ex_tech='SIP' and"
						+ " ex_tech_id=a.id and ex_te_id=:tenant_id";
			} else {
				queryStr = "select a.name,a.regserver,n.noId from ExExtension,NoNode n,Sipfriend a where"
						+ " regserver=no_peername and ex_te_id=:tenant_id and ex_number=:extension_number"
						+ " and ex_tech='SIP' and ex_tech_id=id";
			}

		}
			break;

		case "PJSIP": {
			queryStr = "select a.id as name,b.regServer,n.noId from"
					+ " ExExtension,PsEndpoint a,PsContact b,NoNode n where ex_number=:extension_number"
					+ " and ex_te_id=:tenant_id and ex_tech='PJSIP' and ex_tech_id=tech_id and"
					+ " a.id=b.endpoint and b.regServer=no_peername";

		}
			break;

		default:
			throw new UnsupportedOperationException(String.format("AMI error: unsupported: %s", exTech));
		}

		return queryStr;
	}

	/**
	 * Retrieve asterisk server infos
	 * 
	 * @param queryStr query string
	 * @param exNumber extension number
	 * @param tenantId tennand id
	 * @return a object containing all needed informations. @see AsteriskServerInfos
	 */
	public AsteriskServerInfos retrieveAsteriskServerInfos(String queryStr, String exNumber, Integer tenantId) {

		Query<Object[]> query = getSession().createQuery(queryStr, Object[].class);

		query.setParameter("extension_number", exNumber);
		query.setParameter("tenant_id", tenantId);

		query.setMaxResults(1);

		List<Object[]> result = query.getResultList();

		if (result.size() > 0) {
			// first row only
			Object[] row = result.get(0);

			return new AsteriskServerInfos(row[0].toString(), row[1].toString(), (Integer) row[2]);
		} else {
			System.err.println("query returned empty result");
		}

		return null;

	}

}
