package com.amirouter.server.util;

import java.util.List;

import com.amirouter.server.asterisk.AsteriskInfo;

/**
 * Class that contain configuration (host/port) of the amirouter server and the
 * list of the remote asterisk servers connection informations.
 */
public class ServerConfig {

	private String listenHost;
	private int listenPort;
	private boolean usesipregs;
	private List<AsteriskInfo> asteriskServers;

	/**
	 * Constructor
	 * 
	 * @param listenHost      the host where amirouter server will be running
	 * @param listenPort      the port exposed by the amirouter server for clients
	 *                        connections
	 * @param asteriskServers the list of the remote asterisk servers and their
	 *                        connection informations.
	 */
	public ServerConfig(String listenHost, int listenPort, boolean usesipregs, List<AsteriskInfo> asteriskServers) {
		this.listenHost = listenHost;
		this.listenPort = listenPort;
		this.usesipregs = usesipregs;
		this.asteriskServers = asteriskServers;
	}

	/**
	 * Default constructor (required for serialization)
	 */
	public ServerConfig() {
	}

	/**
	 * Get the host where amirouter server will be running
	 * 
	 * @return the host where amirouter server will be running
	 */
	public String getListenHost() {
		return listenHost;
	}

	/**
	 * Set the host where amirouter server will be running
	 * 
	 * @param listenHost the new host where amirouter server will be running
	 */
	public void setListenHost(String listenHost) {
		this.listenHost = listenHost;
	}

	/**
	 * Get the port exposed by the amirouter server for clients connections
	 * 
	 * @return the port exposed by the amirouter server for clients connections
	 */
	public int getListenPort() {
		return listenPort;
	}

	/**
	 * Set the port exposed by the amirouter server for clients connections
	 * 
	 * @param listenPort the new port exposed by the amirouter server for clients
	 *                   connections
	 */
	public void setListenPort(int listenPort) {
		this.listenPort = listenPort;
	}

	/**
	 * @return the usesipregs
	 */
	public boolean isUsesipregs() {
		return usesipregs;
	}

	/**
	 * @param usesipregs the usesipregs to set
	 */
	public void setUsesipregs(boolean usesipregs) {
		this.usesipregs = usesipregs;
	}

	/**
	 * Get the list of the remote asterisk servers and their connection
	 * informations.
	 * 
	 * @return the list of the remote asterisk servers and their connection
	 *         informations.
	 */
	public List<AsteriskInfo> getAsteriskServers() {
		return asteriskServers;
	}

	/**
	 * Set the list of the remote asterisk servers and their connection
	 * informations.
	 * 
	 * @param asteriskServers the new list of the remote asterisk servers and their
	 *                        connection informations.
	 */
	public void setAsteriskServers(List<AsteriskInfo> asteriskServers) {
		this.asteriskServers = asteriskServers;
	}

	@Override
	public String toString() {
		return "ServerConfig [listenHost=" + listenHost + ", listenPort=" + listenPort + ", usesipregs=" + usesipregs
				+ ", asteriskServers=" + asteriskServers + "]";
	}

}
